@@ -19,13 +19,18 @@ def render_bundle_js(config="DEFAULT"):
 
 
 @register.simple_tag
-def render_bundle_page_css(page_name="main", config="DEFAULT"):
+def render_bundle_page_css(page_name="main", config=None):
+    if not config:
+        config = "DEFAULT"
+
     tags = utils.get_tags_per_page(extension='css', page_name=page_name, config=config)
     return mark_safe('\n'.join(tags))
 
 
 @register.simple_tag
-def render_bundle_page_js(page_name="main", config="DEFAULT"):
+def render_bundle_page_js(page_name="main", config=None):
+    if not config:
+        config = "DEFAULT"
     tags = utils.get_tags_per_page(extension='js', page_name=page_name, config=config)
     return mark_safe('\n'.join(tags))
 
